@@ -51,7 +51,7 @@ xegaGpMutateAllGene<-function(g, lF)
     node$ID, lF$Grammar, min(lF$MaxMutDepth(),node$Rdepth))
   newgene<-xegaDerivationTrees::treeInsert(gene, mutgene, node)
   a<-newgene
-  return(list(evaluated=FALSE, fit=0, gene1=newgene)) }
+  return(list(evaluated=FALSE, evalFail=FALSE, fit=0, gene1=newgene)) }
 
 #' Mutate a gene (with a node filter)
 #'
@@ -109,7 +109,7 @@ xegaGpMutateFilterGene<-function(g, lF)
     node$ID, lF$Grammar, min(lF$MaxMutDepth(),node$Rdepth))
   newgene<-xegaDerivationTrees::treeInsert(gene, mutgene, node)
   a<-newgene
-  return(list(evaluated=FALSE, fit=0, gene1=newgene)) }
+  return(list(evaluated=FALSE, evalFail=FALSE, fit=0, gene1=newgene)) }
 
 #' Configure the mutation function of a genetic algorithm.
 #'
