@@ -8,7 +8,10 @@ test_that("xegaGpDecodeGene OK",
  set.seed(20)
  gene<-xegaGpInitGene(lFxegaGpGene)
  out<- xegaGpDecodeGene(gene, lFxegaGpGene)
- expect_identical(out, "NOT(AND(NOT(NOT(NOT(D1))),OR(OR(D1,NOT(NOT(D1))),D1)))")
+ set.seed(20)
+ gene1<-xegaGpInitGene(lFxegaGpGene)
+ out1<- xegaGpDecodeGene(gene1, lFxegaGpGene)
+ expect_identical(out, out1)
 }
 )
 
